```
Usage: vcd catalog download [OPTIONS] <catalog-name> <item-name> [file-name]

Options:
  -p, --progress / -n, --no-progress
                                  show progress
  -o, --overwrite                 overwrite
  -h, --help                      Show this message and exit.

```
